#
# spec file for package gtksourceview4
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   gtksourceview
Name:           gtksourceview4
Version:        4.8.4
Release:        2.2
Summary:        GTK+ Source Editing Widget
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Projects/GtkSourceView
Source0:        https://download.gnome.org/sources/gtksourceview/4.8/%{_name}-%{version}.tar.xz

BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  valgrind
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(gio-2.0) >= 2.48
BuildRequires:  pkgconfig(gladeui-2.0) >= 3.9
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6

%description
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

%package -n libgtksourceview-4-0
Summary:        GTK+ Source Editing Widget
Group:          System/Libraries
Provides:       %{name} = %{version}
Provides:       lib%{name} = %{version}

%description -n libgtksourceview-4-0
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

%package -n typelib-1_0-GtkSource-4
Summary:        GTK+ Source Editing Widget -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GtkSource-4
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

This package provides the GObject Introspection bindings for
GtkSourceView.

%package -n glade-catalog-gtksourceview4
Summary:        GTK+ Source Editing Widget -- Catalog for Glade
Group:          Development/Tools/GUI Builders
Requires:       glade
Requires:       libgtksourceview-4-0 = %{version}
Supplements:    (glade and %{name}-devel)
Obsoletes:      glade-catalog-gtksourceview <= %{version}
Provides:       glade-catalog-gtksourceview = %{version}

%description -n glade-catalog-gtksourceview4
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

This package provides a catalog for Glade, to allow the use the
GtkSourceView widget in Glade.

%package devel
Summary:        GTK+ Source Editing Widget
Group:          Development/Languages/C and C++
Requires:       libgtksourceview-4-0 = %{version}
Requires:       libgtksourceview4 = %{version}
Requires:       typelib-1_0-GtkSource-4 = %{version}

%description devel
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

%lang_package

%prep
%autosetup -n %{_name}-%{version} -p1

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%meson \
	-Dglade_catalog=true \
	-Dgtk_doc=true \
	%{nil}
%meson_build

%install
%meson_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{_name}-4

%ldconfig_scriptlets -n libgtksourceview-4-0

%files -n libgtksourceview-4-0
%license COPYING
%doc AUTHORS
%{_libdir}/libgtksourceview-4.so.*
%{_datadir}/gtksourceview-4/

%files -n typelib-1_0-GtkSource-4
%{_libdir}/girepository-1.0/GtkSource-4.typelib

%files -n glade-catalog-gtksourceview4
%{_datadir}/glade/catalogs/gtksourceview.xml

%files devel
%{_includedir}/gtksourceview-4/
%{_libdir}/libgtksourceview-4.so
%{_libdir}/pkgconfig/gtksourceview-4.pc
%{_datadir}/gir-1.0/GtkSource-4.gir
%{_datadir}/gtk-doc/html/gtksourceview-4.0/
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gtksourceview-4.*

%files lang -f %{_name}-4.lang

%changelog
* Mon Jan  6 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Drop changes.lang source, request from upstream + gedit no longer
  uses plain gtksourceview. (boo#1205804)
* Fri Nov  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.8.4:
  + Style updates to kate, classic, tango.
  + Language updates to vala, python3, c, cuda, latex.
  + Add unit tests for language specs.
  + Updated translations.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.8.3:
  + Adds support for more Pango font-variants.
  + Style updates to solarized-dark, solarized-light.
  + Language updates to lean, rst, c, gtk-doc, javascript, and
    json.
  + Updated translations.
* Fri Nov  5 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Require libgtksourceview-4-0 instead of gtksourceview4 in the
  devel package: defacto the same package, as the library provides
  the base name, but more explicit and clearer.
- Add libgtksourceview4 Provides to libgtksourceview-4-0 and add a
  explicit Requires in devel subpackage, silence rpmlint.
- Use ldconfig_scriptlets for post(un) handling.
- Update Supplements to current standard.
* Fri Sep  3 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.8.2:
  + New syntax highlighting definition file for: STAR
  + Improved syntax highlighting definition file for: YARA, LLVM
  + GtkSourceMap now avoids animation while scrolling in response
    to clicks. This should help prevent some hysteresis.
  + GObject Introspection fixes
  + Fixed decrement of negative numbers in GtkSourceView
  + Improvements to style schemes: kate
  + Fixed build-time macros for version checking in some scenarios
  + Updated translations.
- Drop d1ed58b2ab82bd5be55881088fc17ff1527511db.patch: fixed
  upstream.
* Thu Apr 22 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add d1ed58b2ab82bd5be55881088fc17ff1527511db.patch: build:
  disable -Werror for incompatible-pointer-types. Works around
  build failure with GCC 11.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.8.1:
  + Fix highlighting in presence of byte-order-marks (BOM).
  + meson.lang: Update keywords to 0.55.3 syntax.
  + cmake.lang: Update keywords to 3.18.2 syntax.
  + go.lang: make "0i" syntax highlight as integer.
  + Updated translations.
* Sat Sep 19 2020 Michael Gorse <mgorse@suse.com>
- Update to version 4.8.0:
  + Bump GTK requirement to 3.24 for gdk_window_move_to_rect().
  + Use gdk_window_move_to_rect() to more reliably position
    completion windows.
  + erb.lang: initial support for ERB.
  + javascript.lang, typescript.lang: various correctness and
    performance improvements.
  + Updated translations.
- Up gtk3 dependency.
* Sat Jun 27 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.6.1:
  + Fix various G-I annotations
  + Improve draw-spaces coloring in solarized-light
  + javascript.lang: Performance improvements
  + c.lang: Fixes for #include preprocessor
  + sql.lang: Language completeness improvements
  + latex.lang: additional keywords
  + sh.lang: improved parameter expansion
  + yara.lang: initial support for YARA
  + Updated translations.
* Sun Mar  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.6.0:
  + cpp.lang: add C++20 keywords.
  + commonlisp.lang: add format directives.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Nov 26 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add pkgconfig(fribidi) BuildRequires: meson checks for it.
* Wed Sep 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.4.0:
  + Set NO_AT_BRIDGE=1 when running automated tests.
  + Speed up GtkSourceView rendering when space drawer is unused.
* Thu Sep  5 2019 <luke@ljones.dev>
- Update to version 4.3.92:
  + New syntax highlighting definition file for: ASCII Doc,
    Dockerfile.
  + Improvements to the syntax highlighting of: CSS, Gradle, HTML,
    C, PHP, YAML, and Grovvy.
  + Performance improvements in line number drawing.
  + GtkSourceView now requires GTK 3.22 or newer.
  + GtkSourceView no longer uses many deprecated APIs from GTK.
  + GtkSourceView now uses fribidi directly to determine
    bidriectional direction for cursors.
  + GtkSourceView now relies on GObject for correct marsharllers as
    well as va_marshallers or provides its own. This improves
    profiling with kernel stack unwinders such as Linux's perf.
  + Visual column detection is improved to use the tab-width
    instead of the indent-width.
  + Support for DnD from GIMPs color palette has been improved.
  + A performance optimization has been added to avoid painting
    mark backgrounds if no GtkSourceMarks have been registered.
  + Updated translations.
* Wed May 29 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Rename glade-catalog-gtksourceview to
  glade-catalog-gtksourceview4: do not use the same name as
  gtksourceview (3.x) is using. The new package is obsoleting the
  old one (including the one from 3.x).
* Sat Mar 16 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.2.0:
  + New syntax highlighting definition file for: Fish, GDScript,
    Solidity, Dart, and Powershell.
  + Improvements to the syntax highlighting of: reStructuredText,
    C++, GAP, CSS, HTML, JavaScript, Groovy, Meson, Python3, and
    Logtalk.
  + Fix testsuite for changes in GLib hashtable ordering.
  + Avoid double entry of languages based on globs.
  + MSVC build improvements.
  + Fix usage of GRegex for offset in text, which fixes a Valgrind
    warning.
  + Ensure CSS is inherted from parent style schemes.
  + Avoid storing GtkTextIter across main-loop boundaries.
  + Fix incorrect transfer annoation for
    gtk_source_buffer_create_source_mark().
  + Various memory leak fixes.
  + Updated translations.
* Thu Sep  6 2018 bjorn.lie@gmail.com
- Update to version 4.0.3:
  + New syntax highlighting definition file for: Gradle and
    Logtalk.
  + Improvements to the syntax highlighting of: JavaScript, LaTeX,
    Haskell, C++, GLSL, and Markdown.
  + Performance improvements to space drawing.
  + Various memory leak fixes.
  + Updated translations.
* Thu Aug 16 2018 luc14n0@linuxmail.org
- Add changes.lang language definition for changes file syntax
  highlighting capabilities.
* Sun Jun 17 2018 bjorn.lie@gmail.com
- Update to version 4.0.2:
  + Fix new compilation warnings (-Wcast-function-type).
  + New syntax highlighting definition file for: SCSS and Less.
  + Improvements to the syntax highlighting of: CSS and Rust.
* Sat May  5 2018 bjorn.lie@gmail.com
- Update to version 4.0.1:
  + New syntax highlighting definition file for: TOML.
  + Improvements to the syntax highlighting of: CSS and XML.
  + Updated translations.
* Sat Mar 10 2018 bjorn.lie@gmail.com
- Update to version 4.0.0:
  + GtkSourceView class: respect the GtkTextView:accepts-tab
    property.
  + New syntax highlighting definition file for: Groovy and Tera
    templates.
  + Improvements to the syntax highlighting of: Erlang and Fortran.
  + Provide an Uncrustify configuration file for the GtkSourceView
    C coding style.
  + Various other improvements and small fixes.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Dec  9 2017 zaitor@opensuse.org
- Update to version 3.99.7:
  + Rename gtk_source_completion_show() to
    gtk_source_completion_start().
  + Drop gconstructor.h, add gtk_source_init() and
    gtk_source_finalize().
  + Improve documentation.
  + New syntax highlighting definition file for: logcat.
  + Improvements to the syntax highlighting of: Python,
    reStructuredText and CMake.
  + Improvements to the Visual Studio builds.
  + Updated translations.
* Wed Oct 18 2017 badshah400@gmail.com
- Update to version 3.99.6:
  + Reduce a lot the number of translatable strings (especially in
  * .lang files), to translate only what makes sense. 630 -> 93
    translatable strings!
  + Build: remove ENABLE_NLS option, always support gettext
    translation, to simplify the code.
  + Fix bug in gtk_source_view_indent_lines().
  + Fix bug to read GtkSourceView 4 *.lang and style scheme files,
    not those from GtkSourceView 3.
  + Code refactorings to prepare for the namespace change.
  + Improvements to the syntax highlighting of: Vala.
  + Improvements to the Visual Studio builds.
  + Various other small improvements.
  + Updated translations.
* Wed Sep  6 2017 luc14n0@linuxmail.org
- Update to version 3.99.5:
  + Avoid type redefinitions.
  + Fix bug when GtkSourceView:indent-width and :tab-width are
    equal.
  + New syntax highlighting definition file for: Swift, Maxima and
    Kotlin.
  + Improvements to the syntax highlighting of: sparql, CSS, bibtex
    and LaTeX.
  + jade.lang: add *.pug to globs.
  + Various other small improvements.
  + Updated translations.
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 3.99.4:
  + The API of the GtkSourceView::move-lines keybinding signal has
    been simplified: the copy parameter has been removed; and the
    count parameter has been replaced by the down boolean.
  + Force visual word movements for RTL text with Ctrl+left/right.
  + Improvements to the Visual Studio builds and add support for
    Visual Studio 2017.
  + Improvements to the syntax highlighting of: Rust and LaTeX.
  + Add mimetype to python3.lang.
  + Misc bug fixes.
  + Various other small improvements.
  + Updated translations.
* Sun Feb 26 2017 dimstar@opensuse.org
- Update to version 3.99.3:
  + Bug fix in GtkSourceGutterRendererPixbuf.
  + Fixes for bugs found by Coverity.
  + Build fixes on MS Windows.
  + New syntax highlighting definition files for: ABNF, HAXE and
    Django template.
  + Improvements to the syntax highlighting of: Meson, CSS, ini,
    Rust and JavaScript.
  + Improvements to the build system.
  + Updated translations.
* Wed Feb  8 2017 jengelh@inai.de
- Drop useless --with-pic (it's for static libs),
  drop useless %%clean.
* Tue Nov 22 2016 dimstar@opensuse.org
- Initial packaging, version 3.99.2. Based on the .spec of
  gtksourceview 3.22.
